@@ -16,11 +16,17 @@
  * change all the "unsigned int" variables to "INT32".  You'll also need
  * to find a malloc() replacement that can allocate more than 64K.
  *
- * To code was copied to ufraw from lcms-1.14 on Jan 2005.
- * Changes: added #ifndef NO_JPEG
+ * To code was copied to UFRaw from lcms-1.14 on Jan 2005.
+ * Changes:
+ * 15-Jun-2005 #ifdef HAVE_LIBJPEG on the entire code
+ *    Jan-2005 added this comment...
  */
 
-#ifndef NO_JPEG
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#ifdef HAVE_LIBJPEG
 
 #include "iccjpeg.h"
 #include <stdlib.h>			/* define malloc() */
@@ -251,4 +257,5 @@ read_icc_profile (j_decompress_ptr cinfo,
 
   return TRUE;
 }
-#endif /*NO_JPEG*/
+
+#endif /*HAVE_LIBJPEG*/
